<?php 
/**
 * Plugin Name: Search Monitor (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/SearchMonitor
 * Description: Some custom reports which are related with search performance for MyThoughtWorks.
 * Author: ThoughtWorks
 * Author URI: https://github.com/TWConnect/piwikPlugin
 * Version: 1.3.2
 */
?><?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\SearchMonitor;

use Exception;
use Piwik\Common;
use Piwik\Db;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class SearchMonitor extends \Piwik\Plugin
{
    /**
     * @see Piwik\Plugin::registerEvents
     */
    public function registerEvents()
    {
        return array(
            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles'
        );
    }

    /**
     * Adds css files for this plugin to the list in the event notification.
     */
    public function getStylesheetFiles(&$stylesheets)
    {
        $stylesheets[] = "plugins/SearchMonitor/stylesheets/GetKeywordRelatedInfo.less";
    }

    public function install()
    {
        try {
            $sql = "CREATE TABLE " . Common::prefixTable('searchmonitor') . " (
                        perday VARCHAR( 50 ) NOT NULL ,
                        bounceCount INT ,
                        bounceTotal INT ,
                        repeatCount INT ,
                        repeatTotal INT ,
                        sumPaceTime INT ,
                        sumVisits INT ,
                        timeLessFive INT ,
                        timeBetFiveAndTen INT ,
                        timeBetTenAndThirty INT ,
                        timeBetThirtyAndSixty INT ,
                        timeMoreSixty INT ,
                        PRIMARY KEY ( perday )
                    )  DEFAULT CHARSET=utf8 ";
            Db::exec($sql);
        } catch (Exception $e) {
            // ignore error if table already exists (1050 code is for 'table already exists')
            if (!Db::get()->isErrNo($e, '1050')) {
                throw $e;
            }
        }
    }
}
